"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.bulkMergePRs = bulkMergePRs;

var _enquirer = require("enquirer");

var _lodash = require("lodash");

var _logSymbols = _interopRequireDefault(require("log-symbols"));

var _pMap = _interopRequireDefault(require("p-map"));

var _pFilter = _interopRequireDefault(require("p-filter"));

var _ghSdk = require("@shelf/gh-sdk");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function bulkMergePRs(org) {
  const items = (0, _lodash.orderBy)(await (0, _ghSdk.listOpenPRs)({
    owner: org,
    searchText: 'label:backend label:dependencies'
  }), ['updated_at'], ['desc']);
  const itemsFiltered = await (0, _pFilter.default)(items, async item => {
    console.log({
      owner: org,
      repo: item.repository_url.split('/')[4],
      pr: item.number
    });

    try {
      const pr = await (0, _ghSdk.getPR)({
        owner: org,
        repo: item.repository_url.split('/')[4],
        pr: item.number
      });
      return pr.mergeable_state === 'clean';
    } catch (error) {
      return true;
    }
  }, {
    concurrency: 20
  }); // eslint-disable-next-line @typescript-eslint/ban-ts-comment
  // @ts-ignore

  const {
    prsToMerge
  } = await (0, _enquirer.prompt)({
    type: 'autocomplete',
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore
    multiple: true,
    name: 'prsToMerge',
    message: 'Pick a PR',
    choices: itemsFiltered.map(item => {
      // eslint-disable-next-line @typescript-eslint/no-unused-vars
      const [_, repoWithPrNumber] = item.url.split(`/${org}/`);
      const [repo, prNumber] = repoWithPrNumber.split('/issues/');
      return `#${prNumber} [${repo}]: ${item.title}`;
    })
  });
  const failedToMergePRsURLs = [];
  const mergedPrsCounts = await (0, _pMap.default)(prsToMerge, async prToMerge => {
    const {
      prNumber,
      repo
    } = /#(?<prNumber>\d+) \[(?<repo>.+)\]/gi.exec(prToMerge).groups;

    try {
      await (0, _ghSdk.approvePR)({
        owner: org,
        repo,
        pr: Number(prNumber)
      });
      console.log(`${_logSymbols.default.info} Approved PR #${prNumber} in ${repo}`);
      await (0, _ghSdk.mergePR)({
        owner: org,
        repo,
        pr: Number(prNumber)
      });
      console.log(`${_logSymbols.default.success} Merged PR #${prNumber} in ${repo}`);
      return 1;
    } catch (error) {
      console.error(`${_logSymbols.default.error} Failed to merge PR #${prNumber} in ${repo}: ${error.message}`);
      failedToMergePRsURLs.push(`https://github.com/${org}/${repo}/pull/${prNumber}`);
      return 0;
    }
  }, {
    concurrency: 10
  });
  console.log(`\n${_logSymbols.default.success} Merged ${(0, _lodash.sum)(mergedPrsCounts)} PRs!`);
  console.log(`\n${_logSymbols.default.error} Failed to merge ${failedToMergePRsURLs.length} PRs!`);
  console.log(failedToMergePRsURLs.join('\n'));
}