"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.compareBranches = compareBranches;
exports.getOrgRepoNames = getOrgRepoNames;
exports.getRepoBranches = getRepoBranches;

var _lodash = _interopRequireDefault(require("lodash"));

var _path = _interopRequireDefault(require("path"));

var _debug = _interopRequireDefault(require("debug"));

var _ghSdk = require("@shelf/gh-sdk");

var _restClient = require("@shelf/gh-sdk/lib/rest-client");

var _package = require("../package.json");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const debug = (0, _debug.default)(`${_package.name}:${_path.default.basename(__filename)}`);

async function getRepoBranches({
  org,
  repo
}) {
  const branches = await (0, _ghSdk.getRepoBranchesNames)({
    owner: org,
    repo
  });
  debug('Loaded branches. Repo: %s, Branches: %o', repo, branches);
  return branches;
}

async function compareBranches({
  org,
  repo
}) {
  const gh = (0, _restClient.getClient)();
  const {
    data
  } = await gh.repos.compareCommits({
    owner: org,
    repo,
    base: 'master',
    head: 'develop'
  });
  return data;
}

async function getOrgRepoNames(org) {
  const orgRepos = await (0, _ghSdk.listOrgRepos)(org);
  return _lodash.default.map(orgRepos.filter(repo => !repo.archived), 'name');
}