"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.askOrg = askOrg;
exports.askOrgAction = askOrgAction;
exports.askRepo = askRepo;
exports.askRepoAction = askRepoAction;

var _inquirer = _interopRequireDefault(require("inquirer"));

var _chalk = _interopRequireDefault(require("chalk"));

var _ora = _interopRequireDefault(require("ora"));

var _lodash = _interopRequireDefault(require("lodash"));

var _enquirer = require("enquirer");

var _logSymbols = _interopRequireDefault(require("log-symbols"));

var _progress = _interopRequireDefault(require("progress"));

var _cliWidth = _interopRequireDefault(require("cli-width"));

var _ghSdk = require("@shelf/gh-sdk");

var _repos = require("./repos");

var _clientRepos = require("./client-repos");

var _format = require("./format");

var _diff = require("./diff");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function askOrg() {
  if (process.env.GH_SHIPIT_ORG) {
    return process.env.GH_SHIPIT_ORG;
  }

  const {
    org
  } = await _inquirer.default.prompt([{
    type: 'list',
    name: 'org',
    message: 'Organization?',

    choices() {
      return (0, _ghSdk.getUserOrgs)();
    }

  }]);
  return org;
}

async function askRepo(org) {
  const repos = await loadRepos(org);
  const choices = await loadDiffsChoices({
    org,
    repos
  });

  if (_lodash.default.isEmpty(choices)) {
    console.log(_logSymbols.default.success, `Nothing to Release!`);
    return process.exit(0);
  }

  const {
    repo
  } = await (0, _enquirer.prompt)({
    type: 'autocomplete',
    name: 'repo',
    message: 'Repository?',
    choices
  });
  return repo;
}

async function askRepoAction({
  org,
  repo
}) {
  const choices = [];
  const {
    ahead_by,
    lastDraftReleaseTag
  } = await (0, _repos.getBranchDiff)({
    org,
    repo
  });

  if (ahead_by > 0) {
    const prepareReleaseActionDescription = (0, _chalk.default)`{dim ${_lodash.default.padStart('(creates a release branch, PR, release notes draft)', (0, _cliWidth.default)() - 24)}}`;
    choices.push({
      name: `Prepare release ${prepareReleaseActionDescription}`,
      value: 'prepare-release'
    });
  }

  if (lastDraftReleaseTag !== '-') {
    choices.push({
      name: `Publish release ${lastDraftReleaseTag}`,
      value: 'publish-release'
    });
  }

  const {
    action
  } = await _inquirer.default.prompt([{
    type: 'list',
    name: 'action',
    message: 'Action?',
    choices
  }]);
  return action;
}

async function askOrgAction() {
  const {
    action
  } = await _inquirer.default.prompt([{
    type: 'list',
    name: 'action',
    message: 'Action?',
    choices: [{
      name: 'Create/Publish Releases & PRs',
      value: 'releases'
    }, {
      name: 'Bulk Merge Renovate bot PRs',
      value: 'bulk-merge-renovate-prs'
    }]
  }]);
  return action;
}

async function loadRepos(org) {
  const reposSpinner = (0, _ora.default)('Loading Repos').start();
  const repos = await (0, _clientRepos.getOrgRepoNames)(org);
  reposSpinner.stop();
  return repos;
}

async function loadDiffsChoices({
  org,
  repos
}) {
  const bar = new _progress.default('Calculating Difference [:bar] :percent   ', {
    total: repos.length,
    clear: true,
    width: (0, _cliWidth.default)()
  });
  const diffs = await (0, _diff.getAllReposDiffs)({
    org,
    repos
  }).onProgress(() => {
    bar.tick(1);
  });
  return (0, _format.formatReposDiffsForChoices)(diffs);
}