"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.publishRelease = publishRelease;

var _logSymbols = _interopRequireDefault(require("log-symbols"));

var _ghSdk = require("@shelf/gh-sdk");

var _github = require("./github");

var _inquirer = require("./inquirer");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function publishRelease({
  org,
  repo
}) {
  try {
    const {
      version,
      releaseId
    } = await (0, _inquirer.askDraftReleaseVersion)({
      org,
      repo
    });
    const prNumber = await (0, _inquirer.askDraftReleasePRNumber)({
      org,
      repo,
      version
    });
    console.log(_logSymbols.default.info, `You are about to publish release ${version} and merge PR to master`);
    await (0, _github.publishDraftRelease)({
      org,
      repo,
      releaseId
    });
    console.log(_logSymbols.default.success, `Release ${version} published`);
    await (0, _ghSdk.mergePR)({
      owner: org,
      repo,
      pr: Number(prNumber)
    });
    console.log(_logSymbols.default.success, `Pull request merged to master`);
    await (0, _github.deleteBranch)({
      org,
      repo,
      name: `release/${version}`
    });
    console.log(_logSymbols.default.success, `Deleted release branch`);
  } catch (error) {
    console.log(_logSymbols.default.error, error.message);
  }
}